==> nextcloud-27.1.5.tgz: nextcloud/apps/logreader/l10n/pt_BR.js <==
OC.L10N.register(
    "logreader",
    {
    "Logging" : "Registro",
    "Errors in the log" : "Erros no log",
    "No errors in the logs since %s" : "Sem erros no logo desde %s",
    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : ["%n erro nos logs desde %s","%n erros nos logs desde %s","%n erros nos logs desde %s"],
    "_%n warning in the logs since %s_::_%n warnings in the logs since %s_" : ["%n alerta nos logs desde %s","%n alertas nos logs desde %s","%n alertas nos logs desde %s"],
    "Log Reader" : "Leitor de Registro",
    "A log reader for Nextcloud" : "Um leitor de logs para Nextcloud",
    "Log reader for Nextcloud" : "Leitor de logs para Nextcloud",
    "Log reader" : "Leitor de log",
    "Open log reader settings" : "Abra as configurações do leitor de log",
    "Log reader settings" : "Configurações do leitor de log",
    "Currently the log file {file} is shown" : "Atualmente, o arquivo de log {file} é mostrado",
    "Show server log" : "Mostrar registro do servidor",
    "Live view is disabled" : "A visualização ao vivo está desativada",
    "No log file" : "Nenhum arquivo de log",
    "File-based logging must be enabled to access logs from the Web UI." : "O log baseado em arquivo deve ser ativado para acessar os logs da IU da Web.",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "Se você acha que isso é um erro, verifique {setting} em seu {config} e verifique o Manual de administração do Nextcloud.",
    "Level" : "Nível",
    "App" : "Aplicativo",
    "No app in context" : "Nenhum aplicativo no contexto",
    "Time" : "Hora",
    "Copy raw entry" : "Copiar entrada bruta",
    "Copy formatted entry" : "Copiar entrada formatada",
    "Hide exception details" : "Ocultar detalhes da exceção",
    "View exception details" : "Ver detalhes da exceção",
    "Raw log entry" : "Entrada de registro bruto",
    "Log entry successfully copied" : "Entrada de registro copiada com sucesso",
    "Search log entries" : "Pesquisar entradas de registro",
    "Caused by {exception}" : "Causado por {exception}",
    "Line {line}" : "Linha {line}",
    "Filter log levels" : "Filtrar níveis de registro",
    "Time format" : "Formato de hora",
    "Live view" : "Visualização ao vivo",
    "Download logs" : "Registro de downloads",
    "Show local log file" : "Mostrar arquivo de log local",
    "Upload local log file to be displayed" : "Carregue o arquivo de log local a ser exibido",
    "Raw data" : "Dados não tratados",
    "Local time" : "Horário local",
    "UTC time" : "Tempo UTC",
    "Time format used for displaying the timestamp" : "Formato de hora usado para exibir o carimbo de data/hora",
    "(Local log files only support the \"raw\" time format)" : "(Os arquivos de log locais suportam apenas o formato de hora \"bruto\")",
    "Could not change date time format." : "Não foi possível alterar o formato de data e hora.",
    "Polling is disabled because server is not configured to log to file" : "A votação está desativada porque o servidor não está configurado para registrar no arquivo",
    "Polling (live view)" : "Votação (exibição ao vivo)",
    "Could not change live view setting." : "Não foi possível alterar a configuração de exibição ao vivo.",
    "Filter logging levels" : "Filtrar níveis de registro",
    "Could not set logging levels to show" : "Não foi possível definir os níveis de registro para mostrar",
    "Application" : "Inscrição",
    "Message" : "Mensagem",
    "Log entry actions" : "Ações de entrada de registro",
    "Loading older log entries" : "Carregando entradas de log mais antigas",
    "No older log entries available" : "Nenhuma entrada de registro mais antiga disponível",
    "Collapse row" : "Recolher linha",
    "Expand row" : "Expandir linha",
    "Show details" : "Exibir detalhes",
    "Debug" : "Depurar ",
    "Info" : "Informações ",
    "Warning" : "Aviso",
    "Error" : "Erro",
    "Fatal" : "Fatal",
    "Could not load log entries" : "Não foi possível carregar entradas dos logs",
    "Could not fetch new log entries (server unavailable)" : "Não foi possível buscar novas entradas de log (servidor indisponível)",
    "Could not fetch new entries" : "Não foi possível obter novas entradas",
    "Could not copy to clipboard, please copy manually:" : "Não foi possível copiar para a área de transferência, copie manualmente:",
    "\tfrom {address} by {user} at {time}\n" : "\tde {address} por {user} às {time}\n",
    "Error parsing log" : "Registro de análise de erros",
    "Caused by " : "Causado por",
    "Copy" : "Copiar",
    "Copy raw" : "Copia básica",
    "Copy formatted" : "Cópia formatada",
    "No server logs" : "Sem registros no servidor",
    "One or more entries are hidden by the log level filter" : "Uma ou mais entradas estão escondidas pelo filtro de nível de registro",
    "Everything is working fine" : "Tudo está funcionando bem",
    "Load log file" : "Carregar arquivo de log",
    "Invalid log file" : "Arquivo de log inválido ",
    "Log levels" : "Níveis de registro",
    "Log content" : "Conteúdo do registro",
    "Live update" : "Atualização ao vivo",
    "line {line}" : "linha {line}",
    "Download / Upload logs" : "Baixar/carregar registros"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-28.0.3.tgz: nextcloud/apps/logreader/l10n/pt_BR.js <==
OC.L10N.register(
    "logreader",
    {
    "Logging" : "Registro",
    "Errors in the log" : "Erros no log",
    "No errors in the logs since %s" : "Sem erros no logo desde %s",
    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : ["%n erro nos logs desde %s","%n erros nos logs desde %s","%n erros nos logs desde %s"],
    "_%n warning in the logs since %s_::_%n warnings in the logs since %s_" : ["%n alerta nos logs desde %s","%n alertas nos logs desde %s","%n alertas nos logs desde %s"],
    "Log Reader" : "Leitor de Registro",
    "A log reader for Nextcloud" : "Um leitor de logs para Nextcloud",
    "Log reader for Nextcloud" : "Leitor de logs para Nextcloud",
    "Log reader" : "Leitor de log",
    "Open log reader settings" : "Abra as configurações do leitor de log",
    "Log reader settings" : "Configurações do leitor de log",
    "Currently the log file {file} is shown" : "Atualmente, o arquivo de log {file} é mostrado",
    "Show server log" : "Mostrar registro do servidor",
    "Live view is disabled" : "A visualização ao vivo está desativada",
    "No log file" : "Nenhum arquivo de log",
    "File-based logging must be enabled to access logs from the Web UI." : "O log baseado em arquivo deve ser ativado para acessar os logs da IU da Web.",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "Se você acha que isso é um erro, verifique {setting} em seu {config} e verifique o Manual de administração do Nextcloud.",
    "Level" : "Nível",
    "App" : "Aplicativo",
    "No app in context" : "Nenhum aplicativo no contexto",
    "Time" : "Hora",
    "Copy raw entry" : "Copiar entrada bruta",
    "Copy formatted entry" : "Copiar entrada formatada",
    "Hide exception details" : "Ocultar detalhes da exceção",
    "View exception details" : "Ver detalhes da exceção",
    "Raw log entry" : "Entrada de registro bruto",
    "Log entry successfully copied" : "Entrada de registro copiada com sucesso",
    "Search log entries" : "Pesquisar entradas de registro",
    "Caused by {exception}" : "Causado por {exception}",
    "Line {line}" : "Linha {line}",
    "Filter log levels" : "Filtrar níveis de registro",
    "Set log level" : "Definir nível de registro",
    "Time format" : "Formato de hora",
    "Live view" : "Visualização ao vivo",
    "Download/Upload logs" : "Baixar/carregar registros",
    "Download logs" : "Registro de downloads",
    "Show local log file" : "Mostrar arquivo de log local",
    "Upload local log file to be displayed" : "Carregue o arquivo de log local a ser exibido",
    "Ctrl" : "Ctrl",
    "Could not parse local log file" : "Não foi possível analisar o arquivo de log local",
    "Raw data" : "Dados não tratados",
    "Local time" : "Horário local",
    "UTC time" : "Tempo UTC",
    "Time format used for displaying the timestamp" : "Formato de hora usado para exibir o carimbo de data/hora",
    "(Local log files only support the \"raw\" time format)" : "(Os arquivos de log locais suportam apenas o formato de hora \"bruto\")",
    "Could not change date time format." : "Não foi possível alterar o formato de data e hora.",
    "Polling is disabled because server is not configured to log to file" : "A votação está desativada porque o servidor não está configurado para registrar no arquivo",
    "Polling (live view)" : "Votação (exibição ao vivo)",
    "Could not change live view setting." : "Não foi possível alterar a configuração de exibição ao vivo.",
    "Filter logging levels" : "Filtrar níveis de registro",
    "Could not set logging levels to show" : "Não foi possível definir os níveis de registro para mostrar",
    "Set backend loglevel" : "Definir nível de log de back-end",
    "Could not set logging level" : "Não foi possível definir o nível de registro",
    "Application" : "Aplicativo",
    "Message" : "Mensagem",
    "Log entry actions" : "Ações de entrada de registro",
    "Loading older log entries" : "Carregando entradas de log mais antigas",
    "No older log entries available" : "Nenhuma entrada de registro mais antiga disponível",
    "Collapse row" : "Recolher linha",
    "Expand row" : "Expandir linha",
    "Show details" : "Exibir detalhes",
    "Debug" : "Depurar ",
    "Info" : "Informações ",
    "Warning" : "Aviso",
    "Error" : "Erro",
    "Fatal" : "Fatal",
    "Could not load log entries" : "Não foi possível carregar entradas dos logs",
    "Could not fetch new log entries (server unavailable)" : "Não foi possível buscar novas entradas de log (servidor indisponível)",
    "Could not fetch new entries" : "Não foi possível obter novas entradas",
    "Could not copy to clipboard, please copy manually:" : "Não foi possível copiar para a área de transferência, copie manualmente:",
    "\tfrom {address} by {user} at {time}\n" : "\tde {address} por {user} às {time}\n",
    "Error parsing log" : "Registro de análise de erros",
    "Caused by " : "Causado por",
    "Copy" : "Copiar",
    "Copy raw" : "Copia básica",
    "Copy formatted" : "Cópia formatada",
    "No server logs" : "Sem registros no servidor",
    "One or more entries are hidden by the log level filter" : "Uma ou mais entradas estão escondidas pelo filtro de nível de registro",
    "Everything is working fine" : "Tudo está funcionando bem",
    "Load log file" : "Carregar arquivo de log",
    "Invalid log file" : "Arquivo de log inválido ",
    "Log levels" : "Níveis de registro",
    "Log content" : "Conteúdo do registro",
    "Live update" : "Atualização ao vivo",
    "line {line}" : "linha {line}",
    "Download / Upload logs" : "Baixar/carregar registros"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
